@@ -61,7 +61,7 @@ static ipc_type_t *list = itNULL;
 ipc_type_t *
 itLookUp(identifier_t name)
 {
-    register ipc_type_t *it, **last;
+    ipc_type_t *it, **last;
 
     for (it = *(last = &list); it != itNULL; it = *(last = &it->itNext))
 	if (streql(name, it->itName))
@@ -118,10 +118,11 @@ itAlloc(void)
 	strNULL,		/* identifier_t itServerType */
 	strNULL,		/* identifier_t itTransType */
 	strNULL,		/* identifier_t itInTrans */
+	strNULL,		/* identifier_t itInTransPayload */
 	strNULL,		/* identifier_t itOutTrans */
 	strNULL,		/* identifier_t itDestructor */
     };
-    register ipc_type_t *new;
+    ipc_type_t *new;
 
     new = malloc(sizeof *new);
     if (new == itNULL)
@@ -148,7 +149,7 @@ itNameToString(u_int name)
  * when itInLine, itNumber, or itSize changes.
  */
 static void
-itCalculateSizeInfo(register ipc_type_t *it)
+itCalculateSizeInfo(ipc_type_t *it)
 {
     if (it->itInLine)
     {
@@ -188,7 +189,7 @@ itCalculateSizeInfo(register ipc_type_t *it)
  * Every argument's type should have these values filled in.
  */
 static void
-itCalculateNameInfo(register ipc_type_t *it)
+itCalculateNameInfo(ipc_type_t *it)
 {
     if (it->itInNameStr == strNULL)
 	it->itInNameStr = strmake(itNameToString(it->itInName));
@@ -295,7 +296,7 @@ itCheckDeallocate(const ipc_type_t *it, ipc_flags_t flags, dealloc_t dfault,
 }
 
 static enum uselong { NotLong, CanBeLong, ShouldBeLong, MustBeLong, TooLong }
-itUseLong(register const ipc_type_t *it)
+itUseLong(const ipc_type_t *it)
 {
     enum uselong uselong = NotLong;
 
@@ -364,7 +365,7 @@ itCheckIsLong(const ipc_type_t *it, ipc_flags_t flags, boolean_t dfault,
  *  is parsed.
  ******************************************************/
 static void
-itCheckDecl(identifier_t name, register ipc_type_t *it)
+itCheckDecl(identifier_t name, ipc_type_t *it)
 {
     enum uselong uselong;
 
@@ -376,7 +377,9 @@ itCheckDecl(identifier_t name, register ipc_type_t *it)
        limitations in Mig */
 
     if (it->itVarArray) {
-	if ((it->itInTrans != strNULL) || (it->itOutTrans != strNULL))
+	if ((it->itInTrans != strNULL) ||
+	    (it->itInTransPayload != strNULL) ||
+	    (it->itOutTrans != strNULL))
 	    error("%s: can't translate variable-sized arrays", name);
 
 	if (it->itDestructor != strNULL)
@@ -419,6 +422,10 @@ itPrintTrans(const ipc_type_t *it)
        printf("\tInTran:\t\t%s %s(%s)\n",
 	      it->itTransType, it->itInTrans, it->itServerType);
 
+    if (it->itInTransPayload != strNULL)
+       printf("\tInTranPayload:\t\t%s %s\n",
+	      it->itTransType, it->itInTransPayload);
+
     if (it->itOutTrans != strNULL)
        printf("\tOutTran:\t%s %s(%s)\n",
 	      it->itServerType, it->itOutTrans, it->itTransType);
@@ -501,7 +508,7 @@ ipc_type_t *
 itLongDecl(u_int inname, const_string_t instr, u_int outname,
 	   const_string_t outstr, u_int defsize, u_int size, ipc_flags_t flags)
 {
-    register ipc_type_t *it;
+    ipc_type_t *it;
 
     if ((defsize != 0) && (defsize != size))
 	warn("IPC type decl has strange size (%u instead of %u)",
@@ -527,7 +534,7 @@ itLongDecl(u_int inname, const_string_t instr, u_int outname,
 static ipc_type_t *
 itCopyType(const ipc_type_t *old)
 {
-    register ipc_type_t *new = itAlloc();
+    ipc_type_t *new = itAlloc();
 
     *new = *old;
     new->itName = strNULL;
@@ -556,6 +563,7 @@ itResetType(ipc_type_t *old)
     /* reset all special translation/destruction/type info */
 
     old->itInTrans = strNULL;
+    old->itInTransPayload = strNULL;
     old->itOutTrans = strNULL;
     old->itDestructor = strNULL;
     old->itUserType = strNULL;
@@ -571,7 +579,7 @@ itResetType(ipc_type_t *old)
 ipc_type_t *
 itPrevDecl(identifier_t name)
 {
-    register ipc_type_t *old;
+    ipc_type_t *old;
 
     old = itLookUp(name);
     if (old == itNULL)
@@ -590,9 +598,9 @@ itPrevDecl(identifier_t name)
  *	type new = array[*:number] of old;
  */
 ipc_type_t *
-itVarArrayDecl(u_int number, register const ipc_type_t *old)
+itVarArrayDecl(u_int number, const ipc_type_t *old)
 {
-    register ipc_type_t *it = itResetType(itCopyType(old));
+    ipc_type_t *it = itResetType(itCopyType(old));
 
     if (!it->itInLine || it->itVarArray)
 	error("IPC type decl is too complicated");
@@ -623,7 +631,7 @@ itVarArrayDecl(u_int number, register const ipc_type_t *old)
 ipc_type_t *
 itArrayDecl(u_int number, const ipc_type_t *old)
 {
-    register ipc_type_t *it = itResetType(itCopyType(old));
+    ipc_type_t *it = itResetType(itCopyType(old));
 
     if (!it->itInLine || it->itVarArray)
 	error("IPC type decl is too complicated");
@@ -662,7 +670,7 @@ itPtrDecl(ipc_type_t *it)
 ipc_type_t *
 itStructDecl(u_int number, const ipc_type_t *old)
 {
-    register ipc_type_t *it = itResetType(itCopyType(old));
+    ipc_type_t *it = itResetType(itCopyType(old));
 
     if (!it->itInLine || it->itVarArray)
 	error("IPC type decl is too complicated");
@@ -681,8 +689,8 @@ itStructDecl(u_int number, const ipc_type_t *old)
 ipc_type_t *
 itCStringDecl(u_int count, boolean_t varying)
 {
-    register ipc_type_t *it;
-    register ipc_type_t *itElement;
+    ipc_type_t *it;
+    ipc_type_t *itElement;
 
     itElement = itShortDecl(MACH_MSG_TYPE_STRING_C,
 			    "MACH_MSG_TYPE_STRING_C",
